@@ -1,11 +1,11 @@
 package Prometheus::Tiny::Shared;
-$Prometheus::Tiny::Shared::VERSION = '0.021';
+$Prometheus::Tiny::Shared::VERSION = '0.022';
 # ABSTRACT: A tiny Prometheus client with a shared database behind it
 
 use warnings;
 use strict;
 
-use Prometheus::Tiny 0.004;
+use Prometheus::Tiny 0.005;
 use parent 'Prometheus::Tiny';
 
 use Hash::SharedMem qw(shash_open shash_get shash_set shash_cset shash_keys_array shash_group_get_hash);
@@ -86,7 +86,26 @@ sub declare {
   my ($self, $name, %meta) = @_;
 
   my $key = join('-', 'm', $name);
-  shash_set($self->{_shash}, $key, encode_json(\%meta));
+  my $value = encode_json(\%meta);
+
+  return if shash_cset($self->{_shash}, $key, undef, $value);
+
+  my $old = decode_json(shash_get($self->{_shash}, $key));
+
+  if (
+    ((exists $old->{type} ^ exists $meta{type}) ||
+      (exists $old->{type} && $old->{type} ne $meta{type})) ||
+    ((exists $old->{help} ^ exists $meta{help}) ||
+      (exists $old->{help} && $old->{help} ne $meta{help})) ||
+    ((exists $old->{buckets} ^ exists $meta{buckets}) ||
+      (exists $old->{buckets} && (
+      @{$old->{buckets}} ne @{$meta{buckets}} ||
+      grep { $old->{buckets}[$_] != $meta{buckets}[$_] } (0 .. $#{$meta{buckets}})
+      ))
+    )
+  ) {
+    croak "redeclaration of '$name' with mismatched meta";
+  }
 
   return;
 }
